@@ -42,11 +42,11 @@ class CmdMerge(base.BaseCommand):
                                                        strategy=strategy)
 
         # create and write tasks
-        task = mir_storage_ops.create_task(task_type=mirpb.TaskType.TaskTypeMerge,
-                                           task_id=dst_typ_rev_tid.tid,
-                                           message=f"merge: {src_revs} - {ex_src_revs} to {dst_rev}",
-                                           src_revs=src_revs,
-                                           dst_rev=dst_rev)
+        task = mir_storage_ops.create_task_record(task_type=mirpb.TaskType.TaskTypeMerge,
+                                                  task_id=dst_typ_rev_tid.tid,
+                                                  message=f"merge: {src_revs} - {ex_src_revs} to {dst_rev}",
+                                                  src_revs=src_revs,
+                                                  dst_rev=dst_rev)
 
         mir_data = {
             mirpb.MirStorage.MIR_METADATAS: mir_metadatas,
@@ -88,17 +88,29 @@ def merge_with_pb(mir_root: str, src_typ_rev_tids: List[revs_parser.TypRevTid],
         host_mir_annotations.prediction.executor_config = ''
 
     for typ_rev_tid in src_typ_rev_tids[1:]:
+        guest_mir_metadatas, guest_mir_annotations = mir_storage_ops.MirStorageOps.load_multiple_storages(
+            mir_root=mir_root,
+            mir_branch=typ_rev_tid.rev,
+            mir_task_id=typ_rev_tid.tid,
+            ms_list=[mirpb.MirStorage.MIR_METADATAS, mirpb.MirStorage.MIR_ANNOTATIONS],
+            as_dict=False)
         merge_to_mirdatas(host_mir_metadatas=host_mir_metadatas,
                           host_mir_annotations=host_mir_annotations,
-                          mir_root=mir_root,
-                          guest_typ_rev_tid=typ_rev_tid,
+                          guest_mir_metadatas=guest_mir_metadatas,
+                          guest_mir_annotations=guest_mir_annotations,
+                          guest_tvt_typ=tvt_type_from_str(typ_rev_tid.typ),
                           strategy=strategy)
+        logging.info(f"Merged {typ_rev_tid.typ_rev_tid}, total assets: {len(host_mir_metadatas.attributes)}")
 
     for typ_rev_tid in ex_typ_rev_tids:
+        guest_mir_metadatas = mir_storage_ops.MirStorageOps.load_single_storage(
+            mir_root=mir_root,
+            mir_branch=typ_rev_tid.rev,
+            mir_task_id=typ_rev_tid.tid,
+            ms=mirpb.MirStorage.MIR_METADATAS)
         exclude_from_mirdatas(host_mir_metadatas=host_mir_metadatas,
                               host_mir_annotations=host_mir_annotations,
-                              mir_root=mir_root,
-                              ex_rev_tid=typ_rev_tid)
+                              guest_mir_metadatas=guest_mir_metadatas)
 
     return (host_mir_metadatas, host_mir_annotations)
 
